DjangoplicityImageSource
========================

.. currentmodule:: toasty.pipeline.djangoplicity

.. autoclass:: DjangoplicityImageSource
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DjangoplicityImageSource.deserialize
      ~DjangoplicityImageSource.fetch_candidate
      ~DjangoplicityImageSource.get_config_key
      ~DjangoplicityImageSource.make_request
      ~DjangoplicityImageSource.process
      ~DjangoplicityImageSource.query_candidates

   .. rubric:: Methods Documentation

   .. automethod:: deserialize
   .. automethod:: fetch_candidate
   .. automethod:: get_config_key
   .. automethod:: make_request
   .. automethod:: process
   .. automethod:: query_candidates
